@@ -2,24 +2,12 @@
 #' 
 #' @description 
 #' 
-#' \if{html}{
-#'   \figure{gar_logo_1000.png}{googleAnalyticsR}
-#' }
+#' \ifelse{html}{
+#'   \figure{logo.png}{googleAnalyticsR}
+#' }{\strong{googleAnalyticsR}}
 #' 
-#' Follow the online documentation here: \url{https://code.markedmondson.me/googleAnalyticsR/}
+#' Follow the online documentation here: <https://code.markedmondson.me/googleAnalyticsR/>
 #' 
-#' @details 
-#' 
-#'  
-#' You may wish to set the below environment arguments for easier authentication
-#' 
-#' \code{
-#' GA_CLIENT_ID
-#' GA_CLIENT_SECRET
-#' GA_WEB_CLIENT_ID
-#' GA_WEB_CLIENT_SECRET
-#' GA_AUTH_FILE
-#' }
 #' 
 #' @docType package
 #' @name googleAnalyticsR
@@ -28,9 +16,12 @@ NULL
 ## horrible hack https://github.com/tidyverse/magrittr/issues/29
 if(getRversion() >= "2.15.1"){
   utils::globalVariables(c(".",
+                           "account",
                            "accountName",
+                           "account_name",
                            "accountId",
                            "activityType",
+                           "apiName",
                            "ecommerce",
                            "products",
                            "transactionId",
@@ -42,6 +33,7 @@ if(getRversion() >= "2.15.1"){
                            "activityTime",
                            "cd_value",
                            "cd_index",
+                           "displayName",
                            "hit_data",
                            "has_goal",
                            "goals",
@@ -62,11 +54,15 @@ if(getRversion() >= "2.15.1"){
                            "parentLink.href",
                            "parentLink.type",
                            "permissions.local",
+                           "property",
+                           "propertyId",
+                           "property_name",
                            "selfLink",
                            "startTime",
+                           "uiName",
                            "updated",
                            "userRef.email",
                            "uploadTime",
                            "userRef.kind"))
   
-} 
\ No newline at end of file
+} 
